Eight principles guide AEA framework development:

* **Accessibility**: ease of use.
* **Modularity**: encourages module creation, sharing and reuse.
* **Openness**: easily extensible with third-party libraries.
* **Conciseness**: conceptually simple.
* **Value-driven**: drives immediate value.
* **Low entry barriers**: leverages existing programming languages and web protocols.
* **Safety**: safe for the user (economically speaking).     
* **Goal-alignment**: seamless facilitation of users' preferences and goals.

<br />